@@ -1,11 +1,10 @@
 # ABSTRACT: Utilities for Monitoring ElasticSearch
 package App::ElasticSearch::Utilities;
 
-use v5.10;
-use strict;
+use v5.16;
 use warnings;
 
-our $VERSION = '8.5'; # VERSION
+our $VERSION = '8.6'; # VERSION
 
 use App::ElasticSearch::Utilities::HTTPRequest;
 use CLI::Helpers qw(:all);
@@ -62,10 +61,13 @@ use Sub::Exporter -setup => {
         es_apply_index_settings
         es_local_index_meta
         es_flatten_hash
+        es_human_count
+        es_human_size
     )],
     groups => {
         config  => [qw(es_utils_initialize es_globals)],
         default => [qw(es_utils_initialize es_connect es_indices es_request)],
+        human   => [qw(es_human_count es_human_size)],
         indices => [qw(:default es_indices_meta)],
         index   => [qw(:default es_index_valid es_index_fields es_index_days_old es_index_bases)],
     },
@@ -748,7 +750,12 @@ sub es_index_strip_date {
 
     es_utils_initialize() unless keys %DEF;
 
-    if( $index =~ s/[-_]$PATTERN_REGEX{DATE}.*// ) {
+    # Try the Date Pattern
+    if( $index =~ s/[-_]$PATTERN_REGEX{DATE}.*//o ) {
+        return $index;
+    }
+    # Fallback to matching thing-YYYY-MM-DD or thing-YYYY.MM.DD
+    elsif( $index =~ s/[-_]\d{4}([.-])\d{2}\g{1}\d{2}(?:[-_.]\d+)?$// ) {
         return $index;
     }
     return;
@@ -1042,6 +1049,36 @@ sub es_flatten_hash {
 }
 
 
+sub es_human_count {
+    my ($size) = @_;
+
+    my $unit = 'docs';
+    my @units = qw(thousand million billion);
+
+    while( $size > 1000 && @units ) {
+        $size /= 1000;
+        $unit = shift @units;
+    }
+
+    return sprintf "%0.2f %s", $size, $unit;
+}
+
+
+sub es_human_size {
+    my ($size) = @_;
+
+    my $unit = 'b';
+    my @units = qw(Kb Mb Gb Tb);
+
+    while( $size > 1024 && @units ) {
+        $size /= 1024;
+        $unit = shift @units;
+    }
+
+    return sprintf "%0.2f %s", $size, $unit;
+}
+
+
 sub def {
     my($key)= map { uc }@_;
 
@@ -1086,7 +1123,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 8.5
+version 8.6
 
 =head1 SYNOPSIS
 
@@ -1303,6 +1340,21 @@ Returns a hashref
 
 Performs flattening that's compatible with Elasticsearch's flattening.
 
+=head2 es_human_count
+
+Takes a number and returns the number as a string in docs, thousands, millions, or billions.
+
+    1_000     -> "1.00 thousand",
+    1_000_000 -> "1.00 million",
+
+=head2 es_human_size
+
+Takes a number and returns the number as a string in bytes, Kb, Mb, Gb, or Tb using base 1024.
+
+    1024        -> '1.00 Kb',
+    1048576     -> '1.00 Mb',
+    1073741824  -> '1.00 Gb',
+
 =head2 def('key')
 
 Exposes Definitions grabbed by options parsing
