@@ -2,11 +2,11 @@ package App::ElasticSearch::Utilities::HTTPRequest;
 # ABSTRACT: Allow for strange content elements for Elasticsearch APIs
 
 
-use strict;
+use v5.16;
 use warnings;
 no warnings 'uninitialized';
 
-our $VERSION = '8.5'; # VERSION
+our $VERSION = '8.6'; # VERSION
 
 use JSON::MaybeXS;
 use Ref::Util qw(is_ref is_arrayref is_hashref);
@@ -60,7 +60,7 @@ App::ElasticSearch::Utilities::HTTPRequest - Allow for strange content elements
 
 =head1 VERSION
 
-version 8.5
+version 8.6
 
 =head1 SYNOPSIS
 
