@@ -1,10 +1,10 @@
 package App::ElasticSearch::Utilities::QueryString::IP;
 # ABSTRACT: Expand IP CIDR Notation to ES ranges
 
-use strict;
+use v5.16;
 use warnings;
 
-our $VERSION = '8.5'; # VERSION
+our $VERSION = '8.6'; # VERSION
 
 use Net::CIDR::Lite;
 use namespace::autoclean;
@@ -43,7 +43,7 @@ App::ElasticSearch::Utilities::QueryString::IP - Expand IP CIDR Notation to ES r
 
 =head1 VERSION
 
-version 8.5
+version 8.6
 
 =head1 SYNOPSIS
 
